function g = G(x,y,k)
%
% function g = G(x,y,k)
%
% This function evaluates the 2D free-field Green's function for the
% Helmholtz equation.
%
% On entry:
%
% x    is the length 2 position vector of the observation point
% y    is the position vector of the source (same size as x)
% k    is the wave number
%
% On exit:
%
% g    is the value of the free-field Green's function
%
g = -(i/4) * besselh(0,k*norm(x-y));